from datetime import date, timedelta
from classes.PSQLMain import PSQLMain

from classes.model.Order import Order
from classes.data import PSQLMain as dataPSQLMain
from classes.Payment import TP_PAYMENT_TEDDOC, TP_PAYMENT_PIX, TP_PAYMENT_CARTAO
from asc.exceptions import Marketplace as exceptionsMarketplace
class MarketPlaceReader:
    """ Ler dados de pedidos marketplace para processamentos
    """

    def __init__(self,dt_start: date = None, dt_end: date = None):
        """ 
            O sistema captura inicio com 30 dias atrás 
            e final como ontem
            :param dt_start: data do inicio da busca
            :param dt_end: data do fim da busca - Não pode 
            ser maior ou igual a hoje
        """
        dt_today = date.today()

        if dt_end and dt_end > dt_today: 
            raise exceptionsMarketplace.DataFinalMaximoOntem()

        self.dt_start = dt_start or (dt_today - timedelta(days=30))
        self.dt_end = dt_end or (dt_today - timedelta(days=1))

    def get_data(self,where:dict={}):
        modelOrder = Order(distinctPayment=False)
        modelOrder.sets.order = ['"order".id_order DESC, "payment".id_payment',PSQLMain.OSQL_DESC]

        modelOrder.getJoins.append((
            dataPSQLMain.JOIN_INNER,
            '"user"',
            '"user".id_user',
            '"order".id_user',
        ))

        orders = modelOrder.getAll(
            selec=[
                'ticket',
                '"user".name as "userName"',
                '"user".udoc as "userUdoc"',
                'id_payment_type',
                '"order".dt_add',
                '"order".id_order',
                '"order".vl_order_total',
                '"order".vl_order_tax_pagarme',
                '"order".vl_order_tax_marketplace',
                '"order".id_order_status',
                'payment.dt_update',
                'payment.id_payment_status',
                'payment.vl_payment'
            ],
            where=where or None
        )

        return orders
    
    def get_payment_type_str(self,id_payment_type:int=None):
        
        if id_payment_type == TP_PAYMENT_PIX:
            id_payment_type = 'pix'

        if id_payment_type == TP_PAYMENT_CARTAO:
            id_payment_type = 'card'

        if id_payment_type == TP_PAYMENT_TEDDOC:
            id_payment_type = 'ted/doc'

        return id_payment_type